@@ -54,11 +54,13 @@ inline void GDALGetDataLimits(Tin &tMaxValue, Tin &tMinValue)
     tMinValue = std::numeric_limits<Tin>::min();
 
     // Compute the actual minimum value of Tout in terms of Tin.
-    if (std::numeric_limits<Tout>::is_signed && std::numeric_limits<Tout>::is_integer)
+    if (std::numeric_limits<Tout>::is_signed &&
+        std::numeric_limits<Tout>::is_integer)
     {
         // the minimum value is less than zero
-        if (std::numeric_limits<Tout>::digits < std::numeric_limits<Tin>::digits ||
-                        !std::numeric_limits<Tin>::is_integer)
+        if (std::numeric_limits<Tout>::digits <
+                std::numeric_limits<Tin>::digits ||
+            !std::numeric_limits<Tin>::is_integer)
         {
             // Tout is smaller than Tin, so we need to clamp values in input
             // to the range of Tout's min/max values
@@ -73,7 +75,8 @@ inline void GDALGetDataLimits(Tin &tMaxValue, Tin &tMinValue)
     {
         // the output is unsigned, so we just need to determine the max
         /* coverity[same_on_both_sides] */
-        if (std::numeric_limits<Tout>::digits <= std::numeric_limits<Tin>::digits)
+        if (std::numeric_limits<Tout>::digits <=
+            std::numeric_limits<Tin>::digits)
         {
             // Tout is smaller than Tin, so we need to clamp the input values
             // to the range of Tout's max
@@ -81,7 +84,6 @@ inline void GDALGetDataLimits(Tin &tMaxValue, Tin &tMinValue)
         }
         tMinValue = 0;
     }
-
 }
 
 /************************************************************************/
@@ -97,8 +99,7 @@ inline void GDALGetDataLimits(Tin &tMaxValue, Tin &tMinValue)
 template <class T>
 inline T GDALClampValue(const T tValue, const T tMax, const T tMin)
 {
-    return tValue > tMax ? tMax :
-           tValue < tMin ? tMin : tValue;
+    return tValue > tMax ? tMax : tValue < tMin ? tMin : tValue;
 }
 
 /************************************************************************/
@@ -133,17 +134,18 @@ template <> inline bool GDALIsValueInRange<float>(double dfValue)
 /*                          GDALCopyWord()                              */
 /************************************************************************/
 
-template<class Tin, class Tout> struct sGDALCopyWord
+template <class Tin, class Tout> struct sGDALCopyWord
 {
     static inline void f(const Tin tValueIn, Tout &tValueOut)
     {
         Tin tMaxVal, tMinVal;
         GDALGetDataLimits<Tin, Tout>(tMaxVal, tMinVal);
-        tValueOut = static_cast<Tout>(GDALClampValue(tValueIn, tMaxVal, tMinVal));
+        tValueOut =
+            static_cast<Tout>(GDALClampValue(tValueIn, tMaxVal, tMinVal));
     }
 };
 
-template<class Tin> struct sGDALCopyWord<Tin, float>
+template <class Tin> struct sGDALCopyWord<Tin, float>
 {
     static inline void f(const Tin tValueIn, float &fValueOut)
     {
@@ -151,7 +153,7 @@ template<class Tin> struct sGDALCopyWord<Tin, float>
     }
 };
 
-template<class Tin> struct sGDALCopyWord<Tin, double>
+template <class Tin> struct sGDALCopyWord<Tin, double>
 {
     static inline void f(const Tin tValueIn, double &dfValueOut)
     {
@@ -159,7 +161,7 @@ template<class Tin> struct sGDALCopyWord<Tin, double>
     }
 };
 
-template<> struct sGDALCopyWord<double, double>
+template <> struct sGDALCopyWord<double, double>
 {
     static inline void f(const double dfValueIn, double &dfValueOut)
     {
@@ -167,7 +169,7 @@ template<> struct sGDALCopyWord<double, double>
     }
 };
 
-template<> struct sGDALCopyWord<float, float>
+template <> struct sGDALCopyWord<float, float>
 {
     static inline void f(const float fValueIn, float &fValueOut)
     {
@@ -175,7 +177,7 @@ template<> struct sGDALCopyWord<float, float>
     }
 };
 
-template<> struct sGDALCopyWord<float, double>
+template <> struct sGDALCopyWord<float, double>
 {
     static inline void f(const float fValueIn, double &dfValueOut)
     {
@@ -183,16 +185,16 @@ template<> struct sGDALCopyWord<float, double>
     }
 };
 
-template<> struct sGDALCopyWord<double, float>
+template <> struct sGDALCopyWord<double, float>
 {
     static inline void f(const double dfValueIn, float &fValueOut)
     {
-        if( dfValueIn > std::numeric_limits<float>::max() )
+        if (dfValueIn > std::numeric_limits<float>::max())
         {
             fValueOut = std::numeric_limits<float>::infinity();
             return;
         }
-        if( dfValueIn < -std::numeric_limits<float>::max() )
+        if (dfValueIn < -std::numeric_limits<float>::max())
         {
             fValueOut = -std::numeric_limits<float>::infinity();
             return;
@@ -206,7 +208,7 @@ template <class Tout> struct sGDALCopyWord<float, Tout>
 {
     static inline void f(const float fValueIn, Tout &tValueOut)
     {
-        if( CPLIsNan(fValueIn) )
+        if (CPLIsNan(fValueIn))
         {
             tValueOut = 0;
             return;
@@ -218,29 +220,28 @@ template <class Tout> struct sGDALCopyWord<float, Tout>
     }
 };
 
-template<> struct sGDALCopyWord<float, short>
+template <> struct sGDALCopyWord<float, short>
 {
     static inline void f(const float fValueIn, short &nValueOut)
     {
-        if( CPLIsNan(fValueIn) )
+        if (CPLIsNan(fValueIn))
         {
             nValueOut = 0;
             return;
         }
         float fMaxVal, fMinVal;
         GDALGetDataLimits<float, short>(fMaxVal, fMinVal);
-        float fValue = fValueIn >= 0.0f ? fValueIn + 0.5f :
-            fValueIn - 0.5f;
-        nValueOut = static_cast<short>(
-            GDALClampValue(fValue, fMaxVal, fMinVal));
+        float fValue = fValueIn >= 0.0f ? fValueIn + 0.5f : fValueIn - 0.5f;
+        nValueOut =
+            static_cast<short>(GDALClampValue(fValue, fMaxVal, fMinVal));
     }
 };
 
-template<class Tout> struct sGDALCopyWord<double, Tout>
+template <class Tout> struct sGDALCopyWord<double, Tout>
 {
     static inline void f(const double dfValueIn, Tout &tValueOut)
     {
-        if( CPLIsNan(dfValueIn) )
+        if (CPLIsNan(dfValueIn))
         {
             tValueOut = 0;
             return;
@@ -252,63 +253,60 @@ template<class Tout> struct sGDALCopyWord<double, Tout>
     }
 };
 
-template<> struct sGDALCopyWord<double, int>
+template <> struct sGDALCopyWord<double, int>
 {
     static inline void f(const double dfValueIn, int &nValueOut)
     {
-        if( CPLIsNan(dfValueIn) )
+        if (CPLIsNan(dfValueIn))
         {
             nValueOut = 0;
             return;
         }
         double dfMaxVal, dfMinVal;
         GDALGetDataLimits<double, int>(dfMaxVal, dfMinVal);
-        double dfValue = dfValueIn >= 0.0 ? dfValueIn + 0.5 :
-            dfValueIn - 0.5;
-        nValueOut = static_cast<int>(
-            GDALClampValue(dfValue, dfMaxVal, dfMinVal));
+        double dfValue = dfValueIn >= 0.0 ? dfValueIn + 0.5 : dfValueIn - 0.5;
+        nValueOut =
+            static_cast<int>(GDALClampValue(dfValue, dfMaxVal, dfMinVal));
     }
 };
 
-template<> struct sGDALCopyWord<double, std::int64_t>
+template <> struct sGDALCopyWord<double, std::int64_t>
 {
     static inline void f(const double dfValueIn, std::int64_t &nValueOut)
     {
-        if( CPLIsNan(dfValueIn) )
+        if (CPLIsNan(dfValueIn))
         {
             nValueOut = 0;
             return;
         }
         double dfMaxVal, dfMinVal;
         GDALGetDataLimits<double, std::int64_t>(dfMaxVal, dfMinVal);
-        double dfValue = dfValueIn >= 0.0 ? dfValueIn + 0.5 :
-            dfValueIn - 0.5;
+        double dfValue = dfValueIn >= 0.0 ? dfValueIn + 0.5 : dfValueIn - 0.5;
         nValueOut = static_cast<std::int64_t>(
             GDALClampValue(dfValue, dfMaxVal, dfMinVal));
     }
 };
 
-template<> struct sGDALCopyWord<double, short>
+template <> struct sGDALCopyWord<double, short>
 {
     static inline void f(const double dfValueIn, short &nValueOut)
     {
-        if( CPLIsNan(dfValueIn) )
+        if (CPLIsNan(dfValueIn))
         {
             nValueOut = 0;
             return;
         }
         double dfMaxVal, dfMinVal;
         GDALGetDataLimits<double, short>(dfMaxVal, dfMinVal);
-        double dfValue = dfValueIn > 0.0 ? dfValueIn + 0.5 :
-            dfValueIn - 0.5;
-        nValueOut = static_cast<short>(
-            GDALClampValue(dfValue, dfMaxVal, dfMinVal));
+        double dfValue = dfValueIn > 0.0 ? dfValueIn + 0.5 : dfValueIn - 0.5;
+        nValueOut =
+            static_cast<short>(GDALClampValue(dfValue, dfMaxVal, dfMinVal));
     }
 };
 
 // Roundoff occurs for Float32 -> int32 for max/min. Overload GDALCopyWord
 // specifically for this case.
-template<> struct sGDALCopyWord<float, int>
+template <> struct sGDALCopyWord<float, int>
 {
     static inline void f(const float fValueIn, int &nValueOut)
     {
@@ -316,29 +314,32 @@ template<> struct sGDALCopyWord<float, int>
         {
             nValueOut = std::numeric_limits<int>::max();
         }
-        else if (fValueIn <= static_cast<float>(std::numeric_limits<int>::min()))
+        else if (fValueIn <=
+                 static_cast<float>(std::numeric_limits<int>::min()))
         {
             nValueOut = std::numeric_limits<int>::min();
         }
         else
         {
-            nValueOut = static_cast<int>(fValueIn > 0.0f ?
-                fValueIn + 0.5f : fValueIn - 0.5f);
+            nValueOut = static_cast<int>(fValueIn > 0.0f ? fValueIn + 0.5f
+                                                         : fValueIn - 0.5f);
         }
     }
 };
 
 // Roundoff occurs for Float32 -> uint32 for max. Overload GDALCopyWord
 // specifically for this case.
-template<> struct sGDALCopyWord<float, unsigned int>
+template <> struct sGDALCopyWord<float, unsigned int>
 {
     static inline void f(const float fValueIn, unsigned int &nValueOut)
     {
-        if (fValueIn >= static_cast<float>(std::numeric_limits<unsigned int>::max()))
+        if (fValueIn >=
+            static_cast<float>(std::numeric_limits<unsigned int>::max()))
         {
             nValueOut = std::numeric_limits<unsigned int>::max();
         }
-        else if (fValueIn <= static_cast<float>(std::numeric_limits<unsigned int>::min()))
+        else if (fValueIn <=
+                 static_cast<float>(std::numeric_limits<unsigned int>::min()))
         {
             nValueOut = std::numeric_limits<unsigned int>::min();
         }
@@ -349,39 +350,43 @@ template<> struct sGDALCopyWord<float, unsigned int>
     }
 };
 
-// Roundoff occurs for Float32 -> std::int64_t for max/min. Overload GDALCopyWord
-// specifically for this case.
-template<> struct sGDALCopyWord<float, std::int64_t>
+// Roundoff occurs for Float32 -> std::int64_t for max/min. Overload
+// GDALCopyWord specifically for this case.
+template <> struct sGDALCopyWord<float, std::int64_t>
 {
     static inline void f(const float fValueIn, std::int64_t &nValueOut)
     {
-        if (fValueIn >= static_cast<float>(std::numeric_limits<std::int64_t>::max()))
+        if (fValueIn >=
+            static_cast<float>(std::numeric_limits<std::int64_t>::max()))
         {
             nValueOut = std::numeric_limits<std::int64_t>::max();
         }
-        else if (fValueIn <= static_cast<float>(std::numeric_limits<std::int64_t>::min()))
+        else if (fValueIn <=
+                 static_cast<float>(std::numeric_limits<std::int64_t>::min()))
         {
             nValueOut = std::numeric_limits<std::int64_t>::min();
         }
         else
         {
-            nValueOut = static_cast<std::int64_t>(fValueIn > 0.0f ?
-                fValueIn + 0.5f : fValueIn - 0.5f);
+            nValueOut = static_cast<std::int64_t>(
+                fValueIn > 0.0f ? fValueIn + 0.5f : fValueIn - 0.5f);
         }
     }
 };
 
 // Roundoff occurs for Float32 -> std::uint64_t for max. Overload GDALCopyWord
 // specifically for this case.
-template<> struct sGDALCopyWord<float, std::uint64_t>
+template <> struct sGDALCopyWord<float, std::uint64_t>
 {
     static inline void f(const float fValueIn, std::uint64_t &nValueOut)
     {
-        if (fValueIn >= static_cast<float>(std::numeric_limits<std::uint64_t>::max()))
+        if (fValueIn >=
+            static_cast<float>(std::numeric_limits<std::uint64_t>::max()))
         {
             nValueOut = std::numeric_limits<std::uint64_t>::max();
         }
-        else if (fValueIn <= static_cast<float>(std::numeric_limits<std::uint64_t>::min()))
+        else if (fValueIn <=
+                 static_cast<float>(std::numeric_limits<std::uint64_t>::min()))
         {
             nValueOut = std::numeric_limits<std::uint64_t>::min();
         }
@@ -419,7 +424,7 @@ inline void GDALCopyWord(const Tin tValueIn, Tout &tValueOut)
  */
 
 template <class Tin, class Tout>
-inline void GDALCopy4Words(const Tin* pValueIn, Tout* const pValueOut)
+inline void GDALCopy4Words(const Tin *pValueIn, Tout *const pValueOut)
 {
     GDALCopyWord(pValueIn[0], pValueOut[0]);
     GDALCopyWord(pValueIn[1], pValueOut[1]);
@@ -438,11 +443,11 @@ inline void GDALCopy4Words(const Tin* pValueIn, Tout* const pValueOut)
  * @param pValueOut pointer to 8 output values of type Tout.
  */
 
-template<class Tin, class Tout>
-inline void GDALCopy8Words(const Tin* pValueIn, Tout* const pValueOut)
+template <class Tin, class Tout>
+inline void GDALCopy8Words(const Tin *pValueIn, Tout *const pValueOut)
 {
     GDALCopy4Words(pValueIn, pValueOut);
-    GDALCopy4Words(pValueIn+4, pValueOut+4);
+    GDALCopy4Words(pValueIn + 4, pValueOut + 4);
 }
 
 // Needs SSE2
@@ -450,23 +455,23 @@ inline void GDALCopy8Words(const Tin* pValueIn, Tout* const pValueOut)
 
 #include <emmintrin.h>
 
-static inline void GDALCopyXMMToInt32(const __m128i xmm, void* pDest)
+static inline void GDALCopyXMMToInt32(const __m128i xmm, void *pDest)
 {
 #ifdef CPL_CPU_REQUIRES_ALIGNED_ACCESS
-    int n32 = _mm_cvtsi128_si32 (xmm);     // Extract lower 32 bit word
+    int n32 = _mm_cvtsi128_si32(xmm);  // Extract lower 32 bit word
     memcpy(pDest, &n32, sizeof(n32));
 #else
-    *static_cast<int*>(pDest) = _mm_cvtsi128_si32 (xmm);
+    *static_cast<int *>(pDest) = _mm_cvtsi128_si32(xmm);
 #endif
 }
 
-static inline void GDALCopyXMMToInt64(const __m128i xmm, void* pDest)
+static inline void GDALCopyXMMToInt64(const __m128i xmm, void *pDest)
 {
 #ifdef CPL_CPU_REQUIRES_ALIGNED_ACCESS
-    GInt64 n64 = _mm_cvtsi128_si64 (xmm);   // Extract lower 64 bit word
+    GInt64 n64 = _mm_cvtsi128_si64(xmm);  // Extract lower 64 bit word
     memcpy(pDest, &n64, sizeof(n64));
 #else
-    *static_cast<GInt64*>(pDest) = _mm_cvtsi128_si64 (xmm);
+    *static_cast<GInt64 *>(pDest) = _mm_cvtsi128_si64(xmm);
 #endif
 }
 
@@ -478,8 +483,8 @@ static inline void GDALCopyXMMToInt64(const __m128i xmm, void* pDest)
 #include <smmintrin.h>
 #endif
 
-template<>
-inline void GDALCopy4Words(const float* pValueIn, GByte* const pValueOut)
+template <>
+inline void GDALCopy4Words(const float *pValueIn, GByte *const pValueOut)
 {
     __m128 xmm = _mm_loadu_ps(pValueIn);
 
@@ -490,10 +495,11 @@ inline void GDALCopy4Words(const float* pValueIn, GByte* const pValueOut)
     xmm = _mm_add_ps(xmm, p0d5);
     xmm = _mm_min_ps(_mm_max_ps(xmm, p0d5), xmm_max);
 
-    __m128i xmm_i = _mm_cvttps_epi32 (xmm);
+    __m128i xmm_i = _mm_cvttps_epi32(xmm);
 
 #if __SSSE3__
-    xmm_i = _mm_shuffle_epi8(xmm_i, _mm_cvtsi32_si128(0 | (4 << 8) | (8 << 16) | (12 << 24)));
+    xmm_i = _mm_shuffle_epi8(
+        xmm_i, _mm_cvtsi32_si128(0 | (4 << 8) | (8 << 16) | (12 << 24)));
 #else
     xmm_i = _mm_packs_epi32(xmm_i, xmm_i);   // Pack int32 to int16
     xmm_i = _mm_packus_epi16(xmm_i, xmm_i);  // Pack int16 to uint8
@@ -501,8 +507,8 @@ inline void GDALCopy4Words(const float* pValueIn, GByte* const pValueOut)
     GDALCopyXMMToInt32(xmm_i, pValueOut);
 }
 
-template<>
-inline void GDALCopy4Words(const float* pValueIn, GInt16* const pValueOut)
+template <>
+inline void GDALCopy4Words(const float *pValueIn, GInt16 *const pValueOut)
 {
     __m128 xmm = _mm_loadu_ps(pValueIn);
 
@@ -514,17 +520,17 @@ inline void GDALCopy4Words(const float* pValueIn, GInt16* const pValueOut)
     const __m128 m0d5 = _mm_set1_ps(-0.5f);
     const __m128 mask = _mm_cmpge_ps(xmm, p0d5);
     // f >= 0.5f ? f + 0.5f : f - 0.5f
-    xmm = _mm_add_ps(xmm, _mm_or_ps(_mm_and_ps(mask, p0d5),
-                                    _mm_andnot_ps(mask, m0d5)));
+    xmm = _mm_add_ps(
+        xmm, _mm_or_ps(_mm_and_ps(mask, p0d5), _mm_andnot_ps(mask, m0d5)));
 
-    __m128i xmm_i = _mm_cvttps_epi32 (xmm);
+    __m128i xmm_i = _mm_cvttps_epi32(xmm);
 
-    xmm_i = _mm_packs_epi32(xmm_i, xmm_i);   // Pack int32 to int16
+    xmm_i = _mm_packs_epi32(xmm_i, xmm_i);  // Pack int32 to int16
     GDALCopyXMMToInt64(xmm_i, pValueOut);
 }
 
-template<>
-inline void GDALCopy4Words(const float* pValueIn, GUInt16* const pValueOut)
+template <>
+inline void GDALCopy4Words(const float *pValueIn, GUInt16 *const pValueOut)
 {
     __m128 xmm = _mm_loadu_ps(pValueIn);
 
@@ -533,14 +539,14 @@ inline void GDALCopy4Words(const float* pValueIn, GUInt16* const pValueOut)
     xmm = _mm_add_ps(xmm, p0d5);
     xmm = _mm_min_ps(_mm_max_ps(xmm, p0d5), xmm_max);
 
-    __m128i xmm_i = _mm_cvttps_epi32 (xmm);
+    __m128i xmm_i = _mm_cvttps_epi32(xmm);
 
 #if __SSE4_1__
-     xmm_i = _mm_packus_epi32(xmm_i, xmm_i);   // Pack int32 to uint16
+    xmm_i = _mm_packus_epi32(xmm_i, xmm_i);  // Pack int32 to uint16
 #else
     // Translate to int16 range because _mm_packus_epi32 is SSE4.1 only
     xmm_i = _mm_add_epi32(xmm_i, _mm_set1_epi32(-32768));
-    xmm_i = _mm_packs_epi32(xmm_i, xmm_i);   // Pack int32 to int16
+    xmm_i = _mm_packs_epi32(xmm_i, xmm_i);  // Pack int32 to int16
     // Translate back to uint16 range (actually -32768==32768 in int16)
     xmm_i = _mm_add_epi16(xmm_i, _mm_set1_epi16(-32768));
 #endif
@@ -550,8 +556,8 @@ inline void GDALCopy4Words(const float* pValueIn, GUInt16* const pValueOut)
 #ifdef __AVX2__
 
 #include <immintrin.h>
-template<>
-inline void GDALCopy8Words(const float* pValueIn, GByte* const pValueOut)
+template <>
+inline void GDALCopy8Words(const float *pValueIn, GByte *const pValueOut)
 {
     __m256 ymm = _mm256_loadu_ps(pValueIn);
 
@@ -560,18 +566,18 @@ inline void GDALCopy8Words(const float* pValueIn, GByte* const pValueOut)
     ymm = _mm256_add_ps(ymm, p0d5);
     ymm = _mm256_min_ps(_mm256_max_ps(ymm, p0d5), ymm_max);
 
-    __m256i ymm_i = _mm256_cvttps_epi32 (ymm);
+    __m256i ymm_i = _mm256_cvttps_epi32(ymm);
 
-    ymm_i = _mm256_packus_epi32(ymm_i, ymm_i);   // Pack int32 to uint16
-    ymm_i = _mm256_permute4x64_epi64(ymm_i, 0 | (2 << 2)); // AVX2
+    ymm_i = _mm256_packus_epi32(ymm_i, ymm_i);  // Pack int32 to uint16
+    ymm_i = _mm256_permute4x64_epi64(ymm_i, 0 | (2 << 2));  // AVX2
 
     __m128i xmm_i = _mm256_castsi256_si128(ymm_i);
     xmm_i = _mm_packus_epi16(xmm_i, xmm_i);
     GDALCopyXMMToInt64(xmm_i, pValueOut);
 }
 
-template<>
-inline void GDALCopy8Words(const float* pValueIn, GUInt16* const pValueOut)
+template <>
+inline void GDALCopy8Words(const float *pValueIn, GUInt16 *const pValueOut)
 {
     __m256 ymm = _mm256_loadu_ps(pValueIn);
 
@@ -580,19 +586,20 @@ inline void GDALCopy8Words(const float* pValueIn, GUInt16* const pValueOut)
     ymm = _mm256_add_ps(ymm, p0d5);
     ymm = _mm256_min_ps(_mm256_max_ps(ymm, p0d5), ymm_max);
 
-    __m256i ymm_i = _mm256_cvttps_epi32 (ymm);
+    __m256i ymm_i = _mm256_cvttps_epi32(ymm);
 
-    ymm_i = _mm256_packus_epi32(ymm_i, ymm_i);   // Pack int32 to uint16
-    ymm_i = _mm256_permute4x64_epi64(ymm_i, 0 | (2 << 2)); // AVX2
+    ymm_i = _mm256_packus_epi32(ymm_i, ymm_i);  // Pack int32 to uint16
+    ymm_i = _mm256_permute4x64_epi64(ymm_i, 0 | (2 << 2));  // AVX2
 
-    _mm_storeu_si128( reinterpret_cast<__m128i*>(pValueOut), _mm256_castsi256_si128(ymm_i) );
+    _mm_storeu_si128(reinterpret_cast<__m128i *>(pValueOut),
+                     _mm256_castsi256_si128(ymm_i));
 }
 #else
-template<>
-inline void GDALCopy8Words(const float* pValueIn, GUInt16* const pValueOut)
+template <>
+inline void GDALCopy8Words(const float *pValueIn, GUInt16 *const pValueOut)
 {
     __m128 xmm = _mm_loadu_ps(pValueIn);
-    __m128 xmm1 = _mm_loadu_ps(pValueIn+4);
+    __m128 xmm1 = _mm_loadu_ps(pValueIn + 4);
 
     const __m128 p0d5 = _mm_set1_ps(0.5f);
     const __m128 xmm_max = _mm_set1_ps(65535);
@@ -601,51 +608,54 @@ inline void GDALCopy8Words(const float* pValueIn, GUInt16* const pValueOut)
     xmm = _mm_min_ps(_mm_max_ps(xmm, p0d5), xmm_max);
     xmm1 = _mm_min_ps(_mm_max_ps(xmm1, p0d5), xmm_max);
 
-    __m128i xmm_i = _mm_cvttps_epi32 (xmm);
-    __m128i xmm1_i = _mm_cvttps_epi32 (xmm1);
+    __m128i xmm_i = _mm_cvttps_epi32(xmm);
+    __m128i xmm1_i = _mm_cvttps_epi32(xmm1);
 
 #if __SSE4_1__
-    xmm_i = _mm_packus_epi32(xmm_i, xmm1_i);   // Pack int32 to uint16
+    xmm_i = _mm_packus_epi32(xmm_i, xmm1_i);  // Pack int32 to uint16
 #else
     // Translate to int16 range because _mm_packus_epi32 is SSE4.1 only
     xmm_i = _mm_add_epi32(xmm_i, _mm_set1_epi32(-32768));
     xmm1_i = _mm_add_epi32(xmm1_i, _mm_set1_epi32(-32768));
-    xmm_i = _mm_packs_epi32(xmm_i, xmm1_i);   // Pack int32 to int16
+    xmm_i = _mm_packs_epi32(xmm_i, xmm1_i);  // Pack int32 to int16
     // Translate back to uint16 range (actually -32768==32768 in int16)
     xmm_i = _mm_add_epi16(xmm_i, _mm_set1_epi16(-32768));
 #endif
-    _mm_storeu_si128( reinterpret_cast<__m128i*>(pValueOut), xmm_i );
+    _mm_storeu_si128(reinterpret_cast<__m128i *>(pValueOut), xmm_i);
 }
 #endif
 
-
 #ifdef notdef_because_slightly_slower_than_default_implementation
-template<>
-inline void GDALCopy4Words(const double* pValueIn, float* const pValueOut)
+template <>
+inline void GDALCopy4Words(const double *pValueIn, float *const pValueOut)
 {
     __m128d float_posmax = _mm_set1_pd(std::numeric_limits<float>::max());
     __m128d float_negmax = _mm_set1_pd(-std::numeric_limits<float>::max());
     __m128d float_posinf = _mm_set1_pd(std::numeric_limits<float>::infinity());
     __m128d float_neginf = _mm_set1_pd(-std::numeric_limits<float>::infinity());
     __m128d val01 = _mm_loadu_pd(pValueIn);
-    __m128d val23 = _mm_loadu_pd(pValueIn+2);
-    __m128d mask_max = _mm_cmpge_pd( val01, float_posmax );
-    __m128d mask_max23 = _mm_cmpge_pd( val23, float_posmax );
-    val01 = _mm_or_pd(_mm_and_pd(mask_max, float_posinf), _mm_andnot_pd(mask_max, val01));
-    val23 = _mm_or_pd(_mm_and_pd(mask_max23, float_posinf), _mm_andnot_pd(mask_max23, val23));
-    __m128d mask_min = _mm_cmple_pd( val01, float_negmax );
-    __m128d mask_min23 = _mm_cmple_pd( val23, float_negmax );
-    val01 = _mm_or_pd(_mm_and_pd(mask_min, float_neginf), _mm_andnot_pd(mask_min, val01));
-    val23 = _mm_or_pd(_mm_and_pd(mask_min23, float_neginf), _mm_andnot_pd(mask_min23, val23));
-    __m128 val01_s =  _mm_cvtpd_ps ( val01);
-    __m128 val23_s =  _mm_cvtpd_ps ( val23);
+    __m128d val23 = _mm_loadu_pd(pValueIn + 2);
+    __m128d mask_max = _mm_cmpge_pd(val01, float_posmax);
+    __m128d mask_max23 = _mm_cmpge_pd(val23, float_posmax);
+    val01 = _mm_or_pd(_mm_and_pd(mask_max, float_posinf),
+                      _mm_andnot_pd(mask_max, val01));
+    val23 = _mm_or_pd(_mm_and_pd(mask_max23, float_posinf),
+                      _mm_andnot_pd(mask_max23, val23));
+    __m128d mask_min = _mm_cmple_pd(val01, float_negmax);
+    __m128d mask_min23 = _mm_cmple_pd(val23, float_negmax);
+    val01 = _mm_or_pd(_mm_and_pd(mask_min, float_neginf),
+                      _mm_andnot_pd(mask_min, val01));
+    val23 = _mm_or_pd(_mm_and_pd(mask_min23, float_neginf),
+                      _mm_andnot_pd(mask_min23, val23));
+    __m128 val01_s = _mm_cvtpd_ps(val01);
+    __m128 val23_s = _mm_cvtpd_ps(val23);
     __m128i val01_i = _mm_castps_si128(val01_s);
     __m128i val23_i = _mm_castps_si128(val23_s);
     GDALCopyXMMToInt64(val01_i, pValueOut);
-    GDALCopyXMMToInt64(val23_i, pValueOut+2);
+    GDALCopyXMMToInt64(val23_i, pValueOut + 2);
 }
 #endif
 
-#endif //  defined(__x86_64) || defined(_M_X64)
+#endif  //  defined(__x86_64) || defined(_M_X64)
 
-#endif // GDAL_PRIV_TEMPLATES_HPP_INCLUDED
+#endif  // GDAL_PRIV_TEMPLATES_HPP_INCLUDED
